@@ -3,10 +3,10 @@
 SEXP gmrfEdge(
 		SEXP LinvQab, // dense rectangular matrix
 		SEXP points, // SpatialPoints*
-		SEXP params
+		SEXP params,
+		SEXP result
 ){
 
-	SEXP result, typePrecision; // dense symmetric
 	int Nrow, Ncol;
 	double one = 1.0;
 
@@ -17,22 +17,20 @@ SEXP gmrfEdge(
 			LinvQab,
 			R_DimSymbol))[1];
 
-	PROTECT(typePrecision = NEW_CHARACTER(1));
-	SET_STRING_ELT(typePrecision, 0, mkChar("precision"));
-
-	PROTECT(result = maternPoints(
+	maternPoints(
 			points,
+			result,
 			params,
-			typePrecision));
+			ScalarInteger(3));
 
 	//	result = crossprod(LinvQab) + result
 	// blas DSYRK https://www.math.utah.edu/software/lapack/lapack-blas/dsyrk.html
 	F77_NAME(dsyrk)(
 			"L","T", &Ncol, &Nrow,
 			&one, REAL(LinvQab), &Nrow,
-			&one, REAL(GET_SLOT(result, install("x"))), &Ncol
+			&one, REAL(GET_SLOT(result, install("x"))), 
+			&Ncol
 			FCONE FCONE);
 
-	UNPROTECT(2);
-	return result;
+	return R_NilValue;
 }
